## How to contribute to Kathará

:+1::tada: First off, thanks for taking the time to contribute! :tada::+1:

#### Code of Conduct

This project and everyone participating in it is governed by the [Code of Conduct](CODE_OF_CONDUCT.md). 
By participating, you are expected to uphold this code. Please report unacceptable behavior to [contact@kathara.org](mailto:contact@kathara.org).

#### **Did you find a bug?**

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/KatharaFramework/Kathara/issues).

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/KatharaFramework/Kathara/issues/new). 
Be sure to include a **title and clear description**, as much relevant information as possible. Use the bug report template to create the issue.

#### **Did you write a patch that fixes a bug?**

* Open a new GitHub pull request with the patch.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number if applicable.

#### **Do you intend to add a new feature or change an existing one?**

* Open a new GitHub pull request with the new feature. Ensure the PR description clearly describes the new feature and provides proper use cases.

* Open an issue describing the requested feature and the reason you need it (reporting use cases).

Kathará is a volunteer effort. We encourage you to contribute to the project! Thanks! :heart: :heart: :heart:

Kathará Team :rocket:
